@@ -57,8 +57,8 @@ def distance(lons, lats, lev_len = None, t_len = None):
     # 時間、高度、緯度、経度の4次元のデータを計算するために、2次元の緯度経度を4次元にする
     if t_len != None:
         if lev_len != None:
-            lons = np.tile(lons, (lev_len, t_len, 1, 1))
-            lats = np.tile(lats, (lev_len, t_len, 1, 1))
+            lons = np.tile(lons, (t_len, lev_len, 1, 1))
+            lats = np.tile(lats, (t_len, lev_len, 1, 1))
         else:
             lons = np.tile(lons, (t_len, 1, 1))
             lats = np.tile(lats, (t_len, 1, 1))
